mathtools.is_nonnegative_integer_equivalent_number
==================================================

.. autofunction:: abjad.tools.mathtools.is_nonnegative_integer_equivalent_number.is_nonnegative_integer_equivalent_number
